@@ -46,7 +46,6 @@ use English; require Exporter;
 
 # Return library locations
 
-
 sub PDLA_INCLUDE { '"-I'.whereami_any().'/Core"' };
 sub PDLA_TYPEMAP { whereami_any().'/Core/typemap.pdl' };
 # sub PDLA_INST_INCLUDE { '-I'.whereami_any().'/Core' };
@@ -422,6 +421,8 @@ sub pdlpp_postamble {
 	join '',map { my($src,$pref,$mod) = @$_;
 	my $w = whereami_any();
 	$w =~ s%/((PDLA)|(Basic))$%%;  # remove the trailing subdir
+	require ExtUtils::MM;
+	my $oneliner = MM->oneliner(q{exit if \$\$ENV{DESTDIR}; use PDLA::Doc; eval { PDLA::Doc::add_module(q{$mod}); }});
 qq|
 
 $pref.pm: $src
@@ -436,7 +437,7 @@ $pref\$(OBJ_EXT): $pref.c
 
 install ::
 	\@echo "Updating PDLA documentation database...";
-	\$(ABSPERLRUN) -e 'exit if \$\$ENV{DESTDIR}; use PDLA::Doc; eval { PDLA::Doc::add_module(q{$mod}); }; ';
+	$oneliner
 |
 	} (@_)
 }
